@@ -261,7 +261,13 @@ def get_jwt_payload(request, verify=True):
 
     # Get the payload email
     if not verify:
-        return jwt.decode(token, verify=False)
+        return jwt.decode(
+            token,
+            algorithms=["RS256"],
+            options={
+                "verify_signature": False,
+            }
+        )
 
     else:
         return validate_rs256_jwt(token)
@@ -470,7 +476,14 @@ def validate_rs256_jwt(jwt_string):
 
     # Determine which Auth0 Client ID (aud) this JWT pertains to.
     try:
-        jwt_client_id = str(jwt.decode(jwt_string, verify=False)["aud"])
+        jwt_client_id = str(jwt.decode(
+            jwt_string,
+            algorithms=["RS256"],
+            options={
+                "verify_signature": False,
+                "verify_aud": False,
+            }
+        )["aud"])
 
         # Check for custom domain
         domain = getattr(dbmi_settings, "AUTH0_DOMAIN", None)
@@ -581,18 +594,14 @@ def validate_hs256_jwt(jwt_string):
         logger.error("Cannot verify HS256 tokens without client ID and client secret")
         raise PermissionDenied
 
-    # Determine which Auth0 Client ID (aud) this JWT pertains to.
-    jwt_client_id = None
     try:
-        jwt_client_id = str(jwt.decode(jwt_string, verify=False)["aud"])
-
         # Perform the validation
         payload = jwt.decode(
             jwt_string,
             base64.b64decode(dbmi_settings.AUTH0_SECRET, "-_"),
             algorithms=["HS256"],
             leeway=120,
-            audience=jwt_client_id,
+            audience=dbmi_settings.AUTH0_CLIENT_ID,
         )
 
         return payload
@@ -601,7 +610,7 @@ def validate_hs256_jwt(jwt_string):
         logger.debug(
             "JWT Expired: {}".format(e),
             extra={
-                "jwt_client_id": jwt_client_id,
+                "client_id": dbmi_settings.AUTH0_CLIENT_ID,
             },
         )
 
@@ -609,7 +618,7 @@ def validate_hs256_jwt(jwt_string):
         logger.info(
             "Invalid JWT Token: {}".format(e),
             extra={
-                "jwt_client_id": jwt_client_id,
+                "client_id": dbmi_settings.AUTH0_CLIENT_ID,
             },
         )
 
@@ -618,7 +627,7 @@ def validate_hs256_jwt(jwt_string):
             f"Error validating JWT: {e}",
             exc_info=True,
             extra={
-                "jwt_client_id": jwt_client_id,
+                "client_id": dbmi_settings.AUTH0_CLIENT_ID,
             },
         )
 
