@@ -6,4 +6,6 @@ from rest_framework import serializers
 class UserSerializer(serializers.ModelSerializer):
     class Meta:
         model = django_auth.get_user_model()
-        exclude = ['password', ]
+        exclude = [
+            "password",
+        ]
